==> Gitlab-Issue-Listing-Script-v0.2.tar.gz: Gitlab-Issue-Listing-Script-v0.2/html/templates/html/commit-list.php <==
<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/

defined('listpage') or die;
//print_r($project);
?>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Commits: <?php echo htmlspecialchars($commit['project']->name_with_namespace); ?></title>
<!-- <link rel="alternate" type="application/json" href="<?php //echo qs2sef("proj={$project->pkey}",".json");?>"> -->

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">


<!--sphider_noindex-->

<hr />
<?php if ($commit['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($commit['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($commit['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'>Commits: <?php echo htmlspecialchars($commit['project']->name_with_namespace); ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$commit['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($commit['project']->name_with_namespace);?></a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("commitproj={$commit['project']->path_with_namespace}&commit=list");?>">Commits</a></li>
</ul>

<hr />
<h3>Commits</h3>
<div class='commitlist'>

<?php foreach($commit['commits'] as $commit_o): ?>
    <div class="commitrow" onclick="window.location = '<?php echo GILSUtils::qs2sef("commit={$commit_o->id}&commitproj={$commit['project']->path_with_namespace}");?>'">
        <div class="committitle"><?php echo GILSUtils::markdownToHTML($commit_o->title); ?></div>
        <div class="commitid"><a href="<?php echo GILSUtils::qs2sef("commit={$commit_o->id}&commitproj={$commit['project']->path_with_namespace}");?>">
            <?php echo $commit_o->short_id; ?>
        </a>
        <div class="commitauth"><?php echo $commit_o->author_name; ?></div>
        </div>        
        
    </div>

<?php endforeach; ?>

    
    
</div>


<hr />



<br />

<!--/sphider_noindex-->

</body>
</html>

==> Gitlab-Issue-Listing-Script-v0.4.tar.gz: Gitlab-Issue-Listing-Script-v0.4/html/templates/html/commit-list.php <==
<?php
/** Gitlab Issue List Script
*
* Simple script to generate an simple HTML listing of Gitlab Issues from a Private Gitlab Instance
*
* @copyright (C) 2021 B Tasker (http://www.bentasker.co.uk). All rights reserved
* @license GNU GPL V3 - See LICENSE
*
* @version 1.2
*
*/

defined('listpage') or die;
//print_r($project);
?>
<html>
<head>
<meta name="viewport" content="width=device-width, initial-scale=1">
<title>Commits: <?php echo htmlspecialchars($commit['project']->name_with_namespace); ?></title>
<!-- <link rel="alternate" type="application/json" href="<?php //echo qs2sef("proj={$project->pkey}",".json");?>"> -->

<?php require 'head-includes.php'; ?>
</head>
<body itemscope itemtype="http://schema.org/CollectionPage">


<!--sphider_noindex-->

<hr />
<?php if ($commit['project']->avatar_url): ?>
<img 
    class='projavatar-small' src='<?php echo GILSUtils::getAvatarUrl($commit['project']->avatar_url); ?>' 
    alt="project <?php echo htmlspecialchars($commit['project']->name_with_namespace); ?> avatar"
    >
<?php endif; ?>
<h1 itemprop='name'>Commits: <?php echo htmlspecialchars($commit['project']->name_with_namespace); ?></h1>
<hr />
<ul itemprop="breadcrumb" class="breadcrumbs">
        <li><a href="/index.html">Projects</a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("proj={$commit['project']->path_with_namespace}");?>"><?php echo htmlspecialchars($commit['project']->name_with_namespace);?></a></li>
        <li><a href="<?php echo GILSUtils::qs2sef("commitproj={$commit['project']->path_with_namespace}&commit=list");?>">Commits</a></li>
</ul>

<hr />
<h3>Commits</h3>
<div class='commitlist'>

<?php foreach($commit['commits'] as $commit_o): ?>
    <div class="commitrow">
        <div class="committitle"><?php echo GILSUtils::markdownToHTML($commit_o->title); ?></div>
        
        <?php if($commit_o->signature['is_signed']): ?>
            <div class="signature">
                <div class="commit_sig_status commit_sig_stat_<?php echo htmlspecialchars($commit_o->signature['status']); ?>" title='Signed by "<?php echo htmlspecialchars($commit_o->signature['signed_by_user']); ?>" with "<?php echo htmlspecialchars($commit_o->signature['signed_by_key']); ?>"'>
           <?php echo htmlspecialchars($commit_o->signature['status']); ?> 
        </div>
            </div>
        <?php endif; ?>
        <div class="commitid"><a href="<?php echo GILSUtils::qs2sef("commit={$commit_o->id}&commitproj={$commit['project']->path_with_namespace}");?>">
            <?php echo $commit_o->short_id; ?>
        </a>
        <div class="commitauth"><?php echo $commit_o->author_name; ?></div>
        </div>        
        
    </div>

<?php endforeach; ?>

    
    
</div>


<hr />



<br />

<!--/sphider_noindex-->

</body>
</html>
